cli

package
v0.19.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ColorizeCmd

func ColorizeCmd(cmdName string) string

ColorizeCmd returns a string with the command name blue colored and italicized

func Dispatch

func Dispatch(args []string, buildInfo BuildInfoProvider) func()

Dispatch returns the actual command function to run based on the arguments

Types

type BuildInfoProvider

type BuildInfoProvider func() (compileDate string, impulsarVersion string)

BuildInfoProvider is a function that provides impulsar build information

Jump to