Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ColorizeCmd ¶
ColorizeCmd returns a string with the command name blue colored and italicized
func Dispatch ¶
func Dispatch(args []string, buildInfo BuildInfoProvider) func()
Dispatch returns the actual command function to run based on the arguments
Types ¶
type BuildInfoProvider ¶
BuildInfoProvider is a function that provides impulsar build information
Click to show internal directories.
Click to hide internal directories.